chicken_turtle_util.click
=========================

.. automodule:: chicken_turtle_util.click

.. autosummary::
   :nosignatures:

   argument
   assert_runs
   option
   password_option

.. autofunction:: assert_runs